Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(201)

Unified Diff: content/browser/payments/payment_app_manager.h

Issue 2557473003: PaymentApp: Factor out functions to serialize/deserialize manifest data. (Closed)
Patch Set: test Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/payments/payment_app_manager.h
diff --git a/content/browser/payments/payment_app_manager.h b/content/browser/payments/payment_app_manager.h
index 28d2e855a0d32b4f53c709fc40242bd0f0e33125..8f68347b9ccaa732fcf5f89361812cfa98cea819 100644
--- a/content/browser/payments/payment_app_manager.h
+++ b/content/browser/payments/payment_app_manager.h
@@ -16,14 +16,14 @@
namespace content {
-class PaymentAppContext;
+class PaymentAppContextImpl;
class ServiceWorkerRegistration;
class CONTENT_EXPORT PaymentAppManager
: public NON_EXPORTED_BASE(payments::mojom::PaymentAppManager) {
public:
PaymentAppManager(
- PaymentAppContext* payment_app_context,
+ PaymentAppContextImpl* payment_app_context,
mojo::InterfaceRequest<payments::mojom::PaymentAppManager> request);
~PaymentAppManager() override;
@@ -59,8 +59,8 @@ class CONTENT_EXPORT PaymentAppManager
// Called when an error is detected on binding_.
void OnConnectionError();
- // PaymentAppContext owns PaymentAppManager
- PaymentAppContext* payment_app_context_;
+ // PaymentAppContextImpl owns PaymentAppManager
+ PaymentAppContextImpl* payment_app_context_;
mojo::Binding<payments::mojom::PaymentAppManager> binding_;
« no previous file with comments | « content/browser/payments/payment_app_context_impl.cc ('k') | content/browser/payments/payment_app_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698